autowisp.processing_steps.fit_magnitudes module — AutoWISP documentation

# autowisp.processing_steps.fit_magnitudes module

## Class Inheritance Diagram

Apply magnitude fitting to hdf5 files

autowisp.processing_steps.fit_magnitudes.check_no_master(filename, master_type)

  Raise an exception if the given master exists.

autowisp.processing_steps.fit_magnitudes.clean_dr(dr_fname, dr_substitutions)

  Remove a magfit iteration from the given DR file.

autowisp.processing_steps.fit_magnitudes.cleanup_interrupted(interrupted, configuration)

  Remove DR entries stats and magfit references for magfit_iteration.

autowisp.processing_steps.fit_magnitudes.delete_master(filename, master_type)

  Delete the master from file system and database.

autowisp.processing_steps.fit_magnitudes.fit_magnitudes(dr_collection, start_status, configuration, mark_start, mark_end)

  Perform magnitude fitting for the given DR files.

autowisp.processing_steps.fit_magnitudes.get_dr_fnames_and_catalog(dr_collection, configuration, sphotref_header, mark_start, mark_end)

  Return the DR files to process and the catalog.

autowisp.processing_steps.fit_magnitudes.get_path_substitutions(configuration, sphotref_header)

  Return the path substitutions to find magfit datasets.

autowisp.processing_steps.fit_magnitudes.has_apphot(dr_fname, substitutions)

  Check if the DR file contains a sky-to-frame transformation.

autowisp.processing_steps.fit_magnitudes.main()

  Run the step from command line.

autowisp.processing_steps.fit_magnitudes.parse_command_line(*args)

  Return the parsed command line arguments.